---
authors:
  - Zhiyuan Chen
date: 2024-05-04
---

# datasets

`datasets` 提供了一系列广泛使用的数据集。

## 可用数据集

### 脱氧核糖核酸（DNA）

- [GeneCode](datasets/genecode.md)

### 核糖核酸（RNA）

- [RNACentral](datasets/rnacentral.md)
- [Rfam](datasets/rfam.md)
- [bpRNA-1m](datasets/bprna.md)
